==> vdr-addon-tvmovie2vdr_0.1.0.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.0.orig/inc/hoerzufetch.pl <==
#!/usr/bin/perl

sub ReadExternalEPG_hoerzu
{

	$SIG{'INT'}  = \&SIGhandler;
	my $anzahl =0;
        foreach $sender (keys(%chan)) {
		if ($chan{$sender}[1] eq "3") {
			$anzahl++;
		}
	}

	$line = "";
	$channelnumber=0;
	foreach $sender (keys(%chan)) {
		doexit() if $please_exit;

		# Kanal fr hoerzu konfiguriert ?
		next if $chan{$sender}[1] != "3";
		$channelnumber++;
		$id = 1;
		my (@events);
		$prevtime = "";
		$hoerzu_sender = $chan{$sender}[5];
		$radio = 0;
		if ($hoerzu_sender =~ m|^r-(\d+)$|s) {
			$hoerzu_sender = $1;
			$radio = 1;
		}


		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;
			$prevtime="";
			$now_string = DateCalc("today","+ $days days",\$err,0);
			$now_day = UnixDate($now_string, "%d");
			$now_month = UnixDate($now_string, "%m");
			$now_year = UnixDate($now_string, "%Y");
			$datum = UnixDate($now_string, "%Y-%m-%d");
			$hoerzutime = UnixDate("$now_year$now_month$now_day 01:00","%s"); # bei hoerzu fngt der Tag um 01:oo Uhr an ...
			if ($radio == 0) {
				$download = "$hoerzuurl"."sender.php?newday=$hoerzutime&tvchannelid=$hoerzu_sender&timeday=ganztags&submit=Anzeigen";
			} else {
				$download = "$hoerzuradiourl"."senderdetail.php?newday=$hoerzutime&radiochannelid=$hoerzu_sender";
			}
			
			$cachefile = "$downloadprefix" . "hoerzu_" . "$hoerzu_sender" . "_$now_year$now_month$now_day.html";
			print "\nhoerzu: getting channel $sender for $now_day.$now_month.$now_year (channel $channelnumber/". ($anzahl)." - day ". ($days+1) ."/$days2download)\n";
			my $html=GetContent($download,$cachefile);
			$html = decode_entities($html);

			# Blanks am Anfang und am Ende einer Zeile entfernen
			foreach  (split("\n",$html)) {
				$line .= $1 if m|^\s*(.*?)\s*$|;
			}

			################################################################

			# Anfang und Ende wegwerfen
			$line =~ s|.*<H3>.*?$now_day.$now_month.$now_year.*?</H3>(.*)<BR><BR>.*|$1|s;

			if ($radio == 1) {
				$line .= "<BR>";
			}

###############################################################################################
# 
# Parsen der Sendungsbersicht fr einen Sender
#
			while ($line ne "") {
				doexit() if $please_exit;

				# Gibt es berhaupt Infos?
				# last if  ???;

				# Tabellenzeilen aufteilen in Sendung
				$line =~ s|^.*?\* (.*?) .<BR>(.*)$|$2|s;
				$eventline = $1;
				
				last if $eventline eq "";

				our ($anfang,$title, $genre, $event_id, $link) = "";
				our ($prefix,$link,$title,$subtitle,$htmldesc,$summary,$genre)="";
				
				if ($radio == 0) {
					($anfang,$title, $genre) = ($1,$2,$3) if $eventline =~ m|(\d\d:\d\d) Uhr , (.*) , (.*)|;
					($event_id,$link,$anfang,$title, $genre) = ($1,$2,$3,$4,$5) if $eventline =~ m|<a name='(\d+)'></A><A HREF='(.*?)'>(\d\d:\d\d) Uhr , (.*) , (.*?)</A>|;
				} else {
					($anfang,$title) = ($1,$2) if $eventline =~ m|(\d\d:\d\d) Uhr , (.*)\s*|;
					($event_id,$link,$anfang,$title) = ($1,$2,$3,$4) if $eventline =~ m|<a name='(\d+)'></A><A HREF='(.*?)'>(\d\d:\d\d) Uhr , (.*)</A>|;
				}

				# Regionalsendungen auf ARD usw .. weg damit.
				next if $title =~ m|, Region |;

				# Minuten Seit Tagesanfang merken fr Datumsberlauf
				$minutesstart = $1*60+$2 if $anfang =~ m/^(.*?):(.*?)$/;
				if ($prevtime eq "") {
					$prevtime = $minutesstart;
				}

				# Datumsberlauf in der Startzeit?
				if ($prevtime > $minutesstart) {
					$prevtime = $minutesstart;
					$datum = DateCalc($datum,"+ 1 day",\$err,0);
					$datum = UnixDate($datum, "%Y-%m-%d");
				}
				$start = UnixDate("$datum $anfang", "%s");



###############################################################################################
# 
# Parsen einer einzelnen Sendung
#
				if ($link ne "") {
					doexit() if $please_exit;

					# Link folgen, damit die Beschreibung geholt werden kann
					# caching
					$cachefile = "$downloadprefix" . "hoerzu_" . "$hoerzu_sender" . "_$event_id" . "_$now_year$now_month$now_day.html";
					if ($radio == 0) {
						$download = "$hoerzuurl$link";
					} else {
						$download = "$hoerzuradiourl$link";
					}
					print "hoerzu: getting $event_id ($datum $anfang $title)\n";
					my $htmldesc=GetContent($download,$cachefile);

					$htmldesc = decode_entities($htmldesc);
					ParseContenthoerzu($htmldesc);

				}
				push(@events, {
					start        => $start, 
					stop         => "", 
					duration     => "",
					title        => $title, 
					subtitle     => $subtitle, 
					summary      => $summary, 
					id           => $id,    
					state        => 1, # normale Sendung
					event_id     => $event_id 
				});
				$id++;
			} # while ($line ne "")
		} # for ($days=0;$days < $days2download ;$days++) 

		# EPG-Daten sortieren, doppelte rausfiltern
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
#			next if (UnixDate("today", "%s") > $start); # ist die Sendung schon vorbei ?
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];


		$last_event_id = 0;
		# fehlende Information (ende/dauer/epg_id) berechnen
		for ($i=1; $i < $#{$XML{$sender}}; $i++) {
			doexit() if $please_exit;
			@{$XML{$sender}}[$i-1]->{stop} = @{$XML{$sender}}[$i]->{start};

			$last_event_id++ unless $last_event_id == 0; # Nur Mitzhlen, falls Startwert gefunden

			if (@{$XML{$sender}}[$i-1]->{event_id} ne "") {
				$last_event_id = @{$XML{$sender}}[$i-1]->{event_id};
			}

			if (@{$XML{$sender}}[$i-1]->{event_id} eq "" && $last_event_id != 0) {
				@{$XML{$sender}}[$i-1]->{event_id} = $last_event_id;
			}
			@{$XML{$sender}}[$i-1]->{duration} = @{$XML{$sender}}[$i-1]->{stop} - @{$XML{$sender}}[$i-1]->{start}
		}

		# *sight*
		# Nochmal rckwrts durchlaufen, da Sendungen am Anfang keine EPG-IDs bekommen haben.
		$last_event_id = 0;
		for ($i=$#{$XML{$sender}}; $i >=0; $i--) {
			doexit() if $please_exit;
			$last_event_id-- unless $last_event_id == 0; # Nur Mitzhlen, falls Startwert gefunden

			if (@{$XML{$sender}}[$i]->{event_id} ne "") {
				$last_event_id = @{$XML{$sender}}[$i]->{event_id};
			}

			if (@{$XML{$sender}}[$i]->{event_id} eq "" && $last_event_id != 0) {
				@{$XML{$sender}}[$i]->{event_id} = $last_event_id;
			}
		}

		# *sight*
		# Alle EPG-IDs, die irgendwie durchzuzhlen waren, sind zugewiesen. Wenn jedoch 
		# Ein Sender GARKEINE detailinformationen hat (mtv2), dann gabs keine einzige ID,
		# also als "last try" die Startzeit eintragen.

		for ($i=0; $i <= $#{$XML{$sender}}; $i++) {
			doexit() if $please_exit;
			next if @{$XML{$sender}}[$i]->{event_id} ne "";
			@{$XML{$sender}}[$i]->{event_id} =   (@{$XML{$sender}}[$i]->{start} / 60) % 0xFFFF;
			}

	} # foreach $sender (keys(%chan))
} # sub ReadExternalEPG




###############################################################################################
# 
# Parsen der Sendungsdetails
#
sub ParseContenthoerzu {
	$SIG{'INT'}  = \&SIGhandler;
	my $htmldesc = shift;
	my $linedesc = "";
	$loglength = length($htmldesc);
	$loggeslength = $loggeslength + $loglength;
	open(LOG, ">> download.log") || die "cannot write to download.log file: $!";
	print LOG "$loggeslenght\t\t$loglenght\t$http_base$link\n";
	close LOG;

	# Blanks am Anfang und am Ende einer Zeile entfernen
	foreach  (split("\n",$htmldesc)) {
		$linedesc .= $1 if m|^\s*(.*?)\s*$|;
	}

	doexit() if $please_exit;

	# berschrift und backlink entfernen, nur daswichtige behalten
	$linedesc =~ s|^.*?</SPAN><BR>(.*)<A HREF=|$1|s;

	# in $head kommt Serienuntertitel, Genre, Jahr und Spielzeit, in $summary der Rest.
	if ($radio == 0) {
		($head,$bewertung,$summary) = ($1,$2,$3) if $linedesc=~ m|^(.*?)\.<BR><BR>.*?Detailinformationen:(.*?)<BR><BR>(.*?)\.<BR><BR>|s;
		# Wenn subtitle vorhanden, zuweisen und aus head lschen
		$subtitle =$1 if $head =~ s|^(.*?) ,<BR>(.*)$|$2|s;
	} else {
		$summary = $1 if $linedesc=~ m|.*?Detailinformationen:<BR>(.*?)\.<BR><BR>|s;
		# Wenn subtitle vorhanden, zuweisen und aus summary lschen
		$subtitle =$1 if $summary =~ s|^(.*?)<BR>(.*)$|$2|s;
	}


	# Bewertung subern
	$bewertung =~ s|<BR>||s;
	$bewertung =~ s|\s*,\s*||s;
	
	#genre ermitteln
	$genre = $1 if $head =~ m|^(.*?)\s*,\s*Spielzeit.*|s;

	$genre .= " * Folge $1 von $2" if $head =~ m|Spielzeit:.*, Folge (\d+) von (\d+) Folgen|s;
	$summary = "Genre: $genre|$summary";
}

return 1;

==> vdr-addon-tvmovie2vdr_0.1.5.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.5.orig/inc/hoerzufetch.pl <==
#!/usr/bin/perl

sub ReadExternalEPG_hoerzu
{

	$SIG{'INT'}  = \&SIGhandler;
	my $anzahl =0;
        foreach $sender (keys(%chan)) {
		if ($chan{$sender}[1] eq "3") {
			$anzahl++;
		}
	}

	$line = "";
	$channelnumber=0;
	foreach $sender (keys(%chan)) {
		doexit() if $please_exit;

		# Kanal fr hoerzu konfiguriert ?
		next if $chan{$sender}[1] != "3";
		$channelnumber++;
		$id = 1;
		my (@events);
		$prevtime = "";
		$hoerzu_sender = $chan{$sender}[5];
		$radio = 0;
		if ($hoerzu_sender =~ m|^r-(\d+)$|s) {
			$hoerzu_sender = $1;
			$radio = 1;
		}


		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;
			$prevtime="";
			$now_string = DateCalc("heute","+ $days tage",\$err,0);
			$now_day = UnixDate($now_string, "%d");
			$now_month = UnixDate($now_string, "%m");
			$now_year = UnixDate($now_string, "%Y");
			$datum = UnixDate($now_string, "%Y-%m-%d");
			$hoerzutime = UnixDate("$now_year$now_month$now_day 01:00","%s"); # bei hoerzu fngt der Tag um 01:oo Uhr an ...
			if ($radio == 0) {
				$download = "$hoerzuurl"."sender.php?newday=$hoerzutime&tvchannelid=$hoerzu_sender&timeday=ganztags&submit=Anzeigen";
			} else {
				$download = "$hoerzuradiourl"."senderdetail.php?newday=$hoerzutime&radiochannelid=$hoerzu_sender";
			}
			
			$cachefile = "$downloadprefix" . "hoerzu_" . "$hoerzu_sender" . "_$now_year$now_month$now_day.html";
			print "\nhoerzu: getting channel $sender for $now_day.$now_month.$now_year (channel $channelnumber/". ($anzahl)." - day ". ($days+1) ."/$days2download)\n";
			my $html=GetContent($download,$cachefile);
			$html = decode_entities($html);

			# Blanks am Anfang und am Ende einer Zeile entfernen
			foreach  (split("\n",$html)) {
				$line .= $1 if m|^\s*(.*?)\s*$|;
			}

			################################################################

			# Anfang und Ende wegwerfen
			$line =~ s|.*<H3>.*?$now_day.$now_month.$now_year.*?</H3>(.*)<BR><BR>.*|$1|s;

			if ($radio == 1) {
				$line .= "<BR>";
			}

###############################################################################################
# 
# Parsen der Sendungsbersicht fr einen Sender
#
			while ($line ne "") {
				doexit() if $please_exit;

				# Gibt es berhaupt Infos?
				# last if  ???;

				# Tabellenzeilen aufteilen in Sendung
				$line =~ s|^.*?\* (.*?) .<BR>(.*)$|$2|s;
				$eventline = $1;
				
				last if $eventline eq "";

				our ($anfang,$title, $genre, $event_id, $link) = "";
				our ($prefix,$link,$title,$subtitle,$htmldesc,$summary,$genre)="";
				
				if ($radio == 0) {
					($anfang,$title, $genre) = ($1,$2,$3) if $eventline =~ m|(\d\d:\d\d) Uhr , (.*) , (.*)|;
					($event_id,$link,$anfang,$title, $genre) = ($1,$2,$3,$4,$5) if $eventline =~ m|<a name='(\d+)'></A><A HREF='(.*?)'>(\d\d:\d\d) Uhr , (.*) , (.*?)</A>|;
				} else {
					($anfang,$title) = ($1,$2) if $eventline =~ m|(\d\d:\d\d) Uhr , (.*)\s*|;
					($event_id,$link,$anfang,$title) = ($1,$2,$3,$4) if $eventline =~ m|<a name='(\d+)'></A><A HREF='(.*?)'>(\d\d:\d\d) Uhr , (.*)</A>|;
				}

				# Regionalsendungen auf ARD usw .. weg damit.
				next if $title =~ m|, Region |;

				# Minuten Seit Tagesanfang merken fr Datumsberlauf
				$minutesstart = $1*60+$2 if $anfang =~ m/^(.*?):(.*?)$/;
				if ($prevtime eq "") {
					$prevtime = $minutesstart;
				}

				# Datumsberlauf in der Startzeit?
				if ($prevtime > $minutesstart) {
					$prevtime = $minutesstart;
					$datum = DateCalc($datum,"+ 1 day",\$err,0);
					$datum = UnixDate($datum, "%Y-%m-%d");
				}
				$start = UnixDate("$datum $anfang", "%s");



###############################################################################################
# 
# Parsen einer einzelnen Sendung
#
				if ($link ne "") {
					doexit() if $please_exit;

					# Link folgen, damit die Beschreibung geholt werden kann
					# caching
					$cachefile = "$downloadprefix" . "hoerzu_" . "$hoerzu_sender" . "_$event_id" . "_$now_year$now_month$now_day.html";
					if ($radio == 0) {
						$download = "$hoerzuurl$link";
					} else {
						$download = "$hoerzuradiourl$link";
					}
					print "hoerzu: getting $event_id ($datum $anfang $title)\n";
					my $htmldesc=GetContent($download,$cachefile);

					$htmldesc = decode_entities($htmldesc);
					ParseContenthoerzu($htmldesc);

				}
				push(@events, {
					start        => $start, 
					stop         => "", 
					duration     => "",
					title        => $title, 
					subtitle     => $subtitle, 
					summary      => $summary, 
					id           => $id,    
					state        => 1, # normale Sendung
					event_id     => $event_id 
				});
				$id++;
			} # while ($line ne "")
		} # for ($days=0;$days < $days2download ;$days++) 

		# EPG-Daten sortieren, doppelte rausfiltern
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
#			next if (UnixDate("heute", "%s") > $start); # ist die Sendung schon vorbei ?
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];


		$last_event_id = 0;
		# fehlende Information (ende/dauer/epg_id) berechnen
		for ($i=1; $i < $#{$XML{$sender}}; $i++) {
			doexit() if $please_exit;
			@{$XML{$sender}}[$i-1]->{stop} = @{$XML{$sender}}[$i]->{start};

			$last_event_id++ unless $last_event_id == 0; # Nur Mitzhlen, falls Startwert gefunden

			if (@{$XML{$sender}}[$i-1]->{event_id} ne "") {
				$last_event_id = @{$XML{$sender}}[$i-1]->{event_id};
			}

			if (@{$XML{$sender}}[$i-1]->{event_id} eq "" && $last_event_id != 0) {
				@{$XML{$sender}}[$i-1]->{event_id} = $last_event_id;
			}
			@{$XML{$sender}}[$i-1]->{duration} = @{$XML{$sender}}[$i-1]->{stop} - @{$XML{$sender}}[$i-1]->{start}
		}

		# *sight*
		# Nochmal rckwrts durchlaufen, da Sendungen am Anfang keine EPG-IDs bekommen haben.
		$last_event_id = 0;
		for ($i=$#{$XML{$sender}}; $i >=0; $i--) {
			doexit() if $please_exit;
			$last_event_id-- unless $last_event_id == 0; # Nur Mitzhlen, falls Startwert gefunden

			if (@{$XML{$sender}}[$i]->{event_id} ne "") {
				$last_event_id = @{$XML{$sender}}[$i]->{event_id};
			}

			if (@{$XML{$sender}}[$i]->{event_id} eq "" && $last_event_id != 0) {
				@{$XML{$sender}}[$i]->{event_id} = $last_event_id;
			}
		}

		# *sight*
		# Alle EPG-IDs, die irgendwie durchzuzhlen waren, sind zugewiesen. Wenn jedoch 
		# Ein Sender GARKEINE detailinformationen hat (mtv2), dann gabs keine einzige ID,
		# also als "last try" die Startzeit eintragen.

		for ($i=0; $i <= $#{$XML{$sender}}; $i++) {
			doexit() if $please_exit;
			next if @{$XML{$sender}}[$i]->{event_id} ne "";
			@{$XML{$sender}}[$i]->{event_id} =   (@{$XML{$sender}}[$i]->{start} / 60) % 0xFFFF;
			}

	} # foreach $sender (keys(%chan))
} # sub ReadExternalEPG




###############################################################################################
# 
# Parsen der Sendungsdetails
#
sub ParseContenthoerzu {
	$SIG{'INT'}  = \&SIGhandler;
	my $htmldesc = shift;
	my $linedesc = "";
	$loglength = length($htmldesc);
	$loggeslength = $loggeslength + $loglength;
	open(LOG, ">> download.log") || die "cannot write to download.log file: $!";
	print LOG "$loggeslenght\t\t$loglenght\t$http_base$link\n";
	close LOG;

	# Blanks am Anfang und am Ende einer Zeile entfernen
	foreach  (split("\n",$htmldesc)) {
		$linedesc .= $1 if m|^\s*(.*?)\s*$|;
	}

	doexit() if $please_exit;

	# berschrift und backlink entfernen, nur daswichtige behalten
	$linedesc =~ s|^.*?</SPAN><BR>(.*)<A HREF=|$1|s;

	# in $head kommt Serienuntertitel, Genre, Jahr und Spielzeit, in $summary der Rest.
	if ($radio == 0) {
		($head,$bewertung,$summary) = ($1,$2,$3) if $linedesc=~ m|^(.*?)\.<BR><BR>.*?Detailinformationen:(.*?)<BR><BR>(.*?)\.<BR><BR>|s;
		# Wenn subtitle vorhanden, zuweisen und aus head lschen
		$subtitle =$1 if $head =~ s|^(.*?) ,<BR>(.*)$|$2|s;
	} else {
		$summary = $1 if $linedesc=~ m|.*?Detailinformationen:<BR>(.*?)\.<BR><BR>|s;
		# Wenn subtitle vorhanden, zuweisen und aus summary lschen
		$subtitle =$1 if $summary =~ s|^(.*?)<BR>(.*)$|$2|s;
	}


	# Bewertung subern
	$bewertung =~ s|<BR>||s;
	$bewertung =~ s|\s*,\s*||s;
	
	#genre ermitteln
	$genre = $1 if $head =~ m|^(.*?)\s*,\s*Spielzeit.*|s;

	$genre .= " * Folge $1 von $2" if $head =~ m|Spielzeit:.*, Folge (\d+) von (\d+) Folgen|s;
	$summary = "Genre: $genre|$summary";
}

return 1;
